Attribute VB_Name = "modCurveFamose"
'================================================================
' Descrizione.....: Routines per il calcolo delle "Curve Famose".
' Nome dei Files..: modCurveFamose
'                   frmCurveFamose.frm, frmCurveFamose.frx
'                   modUtilita.bas
' Data............: 28/6/2002
' Versione........: 1.0 a 32 bits.
' Sistema.........: VB6 sotto Windows NT.
' Scritto da......: F. Languasco 
' E-Mail..........: MC7061@mclink.it
' DownLoads a.....: http://members.xoom.virgilio.it/flanguasco/
'                   http://www.flanguasco.org
'================================================================
'
'   Tutte le routines calcolano ascisse ed ordinate dei
'   punti della curva nei vettori:
'    dX(1 To NPunti, 1 To NRami)
'    dY(1 To NPunti, 1 To NRami)
'   in cui NPunti e' il numero di punti calcolati ed NRami
'   e' il numero di rami della curva (e.g., per Ellisse
'   NRami = 1, per Iperbole NRami = 2).
'   Ogni volta che e' stato possibile ho cercato di
'   calcolare la curva in modo da favorire la continuita'
'   dei valori di ascissa.
'
'   L' elenco delle curve disponibili (e delle loro
'   equazioni) e' nella Function Equazione.
'
'   La maggior parte di queste curve e' tratta da:
'    Famous Curves Index
'    http://www-gap.dcd.st-and.ac.uk/~history/Curves/Curves.html
'
'   Nota: tutti i vettori di queste routines iniziano dall' indice 1.
'
'   Nota: i calcoli delle equazioni nei cicli For ... Next sono
'         stati, volutamente, lasciati in forma completa; qualora
'         fosse necessario ottimizzare per velocita', si potrebbero
'         portare fuori dal ciclo i calcoli delle espressioni che
'         rimangono costanti al suo interno.
'
Option Explicit
Public Sub Tricuspide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = a(2cos(p) + cos(2p))
'    y = a(2sin(p) - sin(2p))
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = a * (2# * Cos(p) + Cos(2# * p))
        dY(I, 1) = a * (2# * Sin(p) - Sin(2# * p))
    Next I
'
'
'
End Sub
Public Function Equazione(ByVal NomeCurva$, _
    ByRef TipoEq$, ByRef Note$, _
    ByRef a$, ByRef b$, ByRef c$, ByRef d$, ByRef t$) As String
'
'   Ritorna l' equazione delle curve, i loro limiti
'   di rappresentazione ed alcuni parametri tipici
'   per il calcolo:
'
    Select Case NomeCurva$
'
        Case "Astroide"
        Equazione = "x = acos(t)" & vbNewLine _
                  & "y = asin(t)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.0"
        t$ = PI2
'
        Case "Cardioide"
        Equazione = "r = 2a(1 + cos(t))"
        TipoEq$ = "Polare:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.0"
        t$ = PI2
'
        Case "Catenaria"
        Equazione = "y = acosh(x/a)"
        TipoEq$ = "Cartesiana:"
        Note$ = "Disegna con:  -t/2 <= x <= t/2"
        a$ = "1.0"
        t$ = "1.0"
'
        Case "Cicloide"
        Equazione = "x = at - bsin(t)" & vbNewLine _
                  & "y = a   - bcos(t)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = ""
        a$ = "1.0"
        b$ = "2.0"
        t$ = "3*" & PI2
'
        Case "Cissoide"
        Equazione = "r = 2atan(p)sin(p)"
        TipoEq$ = "Polare:"
        Note$ = "Disegna con:  -t/2 <= p <= t/2"
        a$ = "1.0"
        t$ = "2.5"
'
        Case "Clotoide"
        Equazione = "x = asqr(PI)FresnelC(p/sqr(PI))" & vbNewLine _
                  & "y = asqr(PI)FresnelS(p/sqr(PI))"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Disegna con:  0 <= p <= t"
        a$ = "1.0"
        t$ = "3.0"
'
        Case "Cocleoide"
        Equazione = "r = asin(t)/t"
        TipoEq$ = "Polare:"
        Note$ = ""
        a$ = "1.0"
        t$ = "2*" & PI2
'
        Case "Concoide"
        Equazione = "r = a + bsec(p)"
        TipoEq$ = "Polare:"
        Note$ = "Disegna con: -t/2 <= p <= t/2" & vbNewLine _
              & "   0 <= t < PI"
        a$ = "3.0"
        b$ = "1.0"
        t$ = "3.0"
'
        Case "Curva di Watt"
        Equazione = "r = b - (asin(t)  sqr(c - acos(t)))"
        TipoEq$ = "Polare:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.5"
        b$ = "4.0"
        c$ = "2.0"
        t$ = PI2
'
        Case "Ellisse"
        Equazione = "x = acos(t)" & vbNewLine _
                  & "y = bsin(t)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "2.0"
        b$ = "1.0"
        t$ = PI2
'
        Case "Epicicloide"
        Equazione = "x = (a + b)cos(t) - bcos((a/b + 1)t)" & vbNewLine _
                  & "y = (a + b)sin(t) - bsin((a/b + 1)t)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = ""
        a$ = "5.0"
        b$ = "3.0"
        t$ = "3*" & PI2
'
        Case "Folium di Cartesio"
        Equazione = "x = 3ap/(1 + p)" & vbNewLine _
                  & "y = 3ap/(1 + p)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Disegna con: -1-t/2 <= p <= -1+t/2"
        a$ = "1.0"
        t$ = "25.0"
'
        Case "Iperbole"
        Equazione = "x = asec(p)" & vbNewLine _
                  & "y = btan(p)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Disegna con: -t/2 <= p <= t/2" & vbNewLine _
              & "   0 <= t < PI"
        a$ = "1.0"
        b$ = "1.0"
        t$ = "3.0"
'
        Case "Ipocicloide"
        Equazione = "x = (a - b)cos(t) + bcos((a/b - 1)t)" & vbNewLine _
                  & "y = (a - b)sin(t) - bsin((a/b - 1)t)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = ""
        a$ = "5.0"
        b$ = "3.0"
        t$ = "3*" & PI2
'
        Case "Kampyle di Eudosso"
        Equazione = "r = b/(acos(p)"
        TipoEq$ = "Polare:"
        Note$ = "Disegna con: -t/2 <= p <= t/2" & vbNewLine _
              & "   0 <= t < PI"
        a$ = "1.0"
        b$ = "1.0"
        t$ = "2.5"
'
        Case "Lituus"
        Equazione = "r = a/p"
        TipoEq$ = "Polare:"
        Note$ = "Disegna con:  0 < p <= t"
        a$ = "1.0"
        t$ = "20.0"
'
        Case "Lumaca di Pascal"
        Equazione = "r = b + 2acos(t)"
        TipoEq$ = "Polare:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.0"
        b$ = "1.0"
        t$ = PI2
'
        Case "Nefroide"
        Equazione = "x = a(3cos(t) - cos(3t))" & vbNewLine _
                  & "y = a(3sin(t) - sin(3t))"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.0"
        t$ = PI2
'
        Case "Parabola"
        Equazione = "y = ax + bx + c"
        TipoEq$ = "Cartesiana:"
        Note$ = "Disegna con:  -t/2 <= x <= t/2"
        a$ = "1.0"
        b$ = "0.0"
        c$ = "0.0"
        t$ = "1.0"
'
        Case "Rosa"
        Equazione = "r = asin(bt)"
        TipoEq$ = "Polare:"
        Note$ = "Se b e' dispari: N lobi = b; t = PI" & vbNewLine _
              & "Se b e' pari: N lobi = 2b; t = 2PI"
        a$ = "1.0"
        b$ = "5"
        t$ = PI
'
        Case "Spirale di Archimede"
        Equazione = "r = at"
        TipoEq$ = "Polare:"
        Note$ = ""
        a$ = "1.0"
        t$ = "20.0"
'
        Case "Spirale di Fermat"
        Equazione = "r = ap"
        TipoEq$ = "Polare:"
        Note$ = "Disegna con:  -t/2 <= p <= t/2"
        a$ = "1.0"
        t$ = "20.0"
'
        Case "Spirale iperbolica"
        Equazione = "r = a/t"
        TipoEq$ = "Polare:"
        Note$ = ""
        a$ = "1.0"
        t$ = "20.0"
'
        Case "Trattrice"
        Equazione = "x = 1/cosh(p)" & vbNewLine _
                  & "y = p - tanh(p)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Disegna con:  -t/2 <= p <= t/2"
        t$ = "10.0"
'
        Case "Tricuspide"
        Equazione = "x = a(2cos(t) + cos(2t))" & vbNewLine _
                  & "y = a(2sin(t) - sin(2t))"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Per curva chiusa:  t = 2PI"
        a$ = "1.0"
        t$ = PI2
'
        Case "Tridente di Newton"
        Equazione = "y = (ap + bp + cp + d) / p"
        TipoEq$ = "Cartesiana:"
        Note$ = "Disegna con: -t/2 <= p <= t/2"
        a$ = "10.0"
        b$ = "1.0"
        c$ = "1.0"
        d$ = "1.0"
        t$ = "4.0"
'
        Case "Versiera d' Agnesi"
        Equazione = "x = ap" & vbNewLine _
                  & "y = a/(1+ p)"
        TipoEq$ = "Parametrica Cartesiana:"
        Note$ = "Disegna con:  -t/2 <= p <= t/2"
        a$ = "1.0"
        t$ = "5.0"
'
    End Select
'
'
'
End Function
Public Sub Parabola(ByVal NPunti&, ByVal a#, ByVal b#, ByVal c#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione cartesiana:
'    y = ax + bx + c
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        dX(I, 1) = p
        dY(I, 1) = a * p ^ 2 + b * p + c
    Next I
'
'
'
End Sub
Public Sub Catenaria(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione cartesiana:
'    y = acosh(x/a)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        dX(I, 1) = p
        dY(I, 1) = a * Cosh(p / a)
    Next I
'
'
'
End Sub
Public Sub TridenteNewton(ByVal NPunti&, _
    ByVal a#, ByVal b#, ByVal c#, ByVal d#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione cartesiana:
'    y = (ap +  bp + cp + d)/p
'
'   Questa curva viene disegnata in modo da evitare la
'   discontinuita' in p = 0.  Il calcolo viene, quindi,
'   diviso in due parti:
'    1) -t/2 <= p <= -dt
'    2) dt <= p <= t/2
'
'   Nota: all' aumentare di NPunti diminuisce il dt, ci si
'         avvicina sempre di piu' alla discontinuita' e di
'         conseguenza aumenta l' estensione del grafico.
'
    Dim I&, p#, dt#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / (2# * CDbl(NPunti))
'
    ' 1 ramo:
    For I = 1 To NPunti
        p = -dt * CDbl(I)
'
        dX(I, 1) = p
        dY(I, 1) = (a * p ^ 3 + b * p ^ 2 + c * p + d) / p
    Next I
'
    ' 2 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I)
'
        dX(I, 2) = p
        dY(I, 2) = (a * p ^ 3 + b * p ^ 2 + c * p + d) / p
    Next I
'
'
'
End Sub
Public Sub FoliumCartesio(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = 3ap/(1 + p)
'    y = 3ap/(1 + p)
'
'   Questa curva viene disegnata in modo da evitare la
'   discontinuita' in p = -1.  Il calcolo viene, quindi,
'   diviso in due parti:
'    1) -1 + dt <= p <= -1 + t1
'    2) -1 - t2 <= p <= -1 - dt
'   E':
'    t1 = t2 = t/2 se NPunti e' pari.
'    t1 = (t - dt)/2; t2 = (t + dt)/2 se NPunti e' dispari.
'
'   Nota: all' aumentare di NPunti diminuisce il dt, ci si
'         avvicina sempre di piu' alla discontinuita' e di
'         conseguenza aumenta l' estensione del grafico.
'
    Dim I&, N2&, p#, dt#
'
    dt = t / CDbl(NPunti)
    N2 = Int(NPunti / 2)
'
    For I = 1 To N2
        p = -1# + dt * CDbl(I)
'
        dX(I, 1) = 3# * a * p / (1# + p ^ 3)
        dY(I, 1) = 3# * a * (p ^ 2) / (1# + p ^ 3)
    Next I
'
    For I = N2 + 1 To NPunti
        p = -1# - dt * CDbl(NPunti - I + 1)
'
        dX(I, 1) = 3# * a * p / (1# + p ^ 3)
        dY(I, 1) = 3# * a * (p ^ 2) / (1# + p ^ 3)
    Next I
'
'
'
End Sub
Public Sub Kampyle(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    x = asec(p)
'    y = btan(p)
'
    Dim I&, N2&, p#, dt#, r#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / CDbl(NPunti - 1)
    N2 = Int(NPunti / 2)
'
    ' 1 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
'
        r = b ^ 2 / (a * Cos(p) ^ 2)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
    ' 2 ramo:
    For I = 1 To NPunti
        dX(I, 2) = -dX(I, 1)
        dY(I, 2) = dY(I, 1)
    Next I
'
'
'
End Sub
Public Sub Concoide(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = a + bsec(p)
'
    Dim I&, p#, r#, dt#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / CDbl(NPunti - 1)
'
    ' 1 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        r = a + b / Cos(p)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
    ' 2 ramo:
    For I = 1 To NPunti
        p = PI + dt * CDbl(I - 1) - t / 2#
'
        r = a + b / Cos(p)
        dX(I, 2) = r * Cos(p)
        dY(I, 2) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub Iperbole(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = asec(p)
'    y = btan(p)
'
    Dim I&, p#, dt#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / CDbl(NPunti - 1)
'
    ' 1 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        dX(I, 1) = a / Cos(p)
        dY(I, 1) = b * Tan(p)
    Next I
'
    ' 2 ramo:
    For I = 1 To NPunti
        dX(I, 2) = -dX(I, 1)
        dY(I, 2) = dY(I, 1)
    Next I
'
'
'
End Sub
Public Sub VersieraAgnesi(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = ap
'    y = a/(1+ p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        dX(I, 1) = a * p
        dY(I, 1) = a / (1# + p ^ 2)
    Next I
'
'
'
End Sub
Public Sub Clotoide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = asqr(PI)FresnelC(p/sqr(PI))
'    y = asqr(PI)FresnelS(p/sqr(PI))
'   Con:
'                   z
'                  /
'    FresnelS(z) = | Sin(PIt/2)dt
'                  /
'                  0
'   e:
'                   z
'                  /
'    FresnelC(z) = | Cos(PIt/2)dt
'                  /
'                  0
'
    Dim I&, p#, dt#, aSqrPI#
    Dim FresnelC_S#, FresnelS_S#
    ReDim Theta#(1 To NPunti)
'
    dt = t / CDbl(NPunti - 1)
    aSqrPI = a * SqrPI
'
    Theta(1) = 0#
    dX(1, 1) = 0#
    dY(1, 1) = 0#
    For I = 2 To NPunti
        Theta(I) = dt * CDbl(I - 1)
'
        FresnelC_S = FresnelC_S + FresnelC(Theta(I - 1), Theta(I), 0.001)
        FresnelS_S = FresnelS_S + FresnelS(Theta(I - 1), Theta(I), 0.001)
'
        dX(I, 1) = aSqrPI * FresnelC_S
        dY(I, 1) = aSqrPI * FresnelS_S
    Next I
'
'
'
End Sub
Public Sub Ipocicloide(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = (a - b)cos(p) + bcos((a/b - 1)p)
'    y = (a - b)sin(p) - bsin((a/b - 1)p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = (a - b) * Cos(p) + b * Cos((a / b - 1) * p)
        dY(I, 1) = (a - b) * Sin(p) - b * Sin((a / b - 1) * p)
    Next I
'
'
'
End Sub
Public Sub Epicicloide(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = (a + b)cos(p) - bcos((a/b + 1)p)
'    y = (a + b)sin(p) - bsin((a/b + 1)p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = (a + b) * Cos(p) - b * Cos((1 + a / b) * p)
        dY(I, 1) = (a + b) * Sin(p) - b * Sin((1 + a / b) * p)
    Next I
'
'
'
End Sub
Public Sub Cicloide(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = ap - bsin(p)
'    y = a   - bcos(p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = a * p - b * Sin(p)
        dY(I, 1) = a - b * Cos(p)
    Next I
'
'
'
End Sub
Public Sub Astroide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = acos(p)
'    y = asin(p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = a * Cos(p) ^ 3
        dY(I, 1) = a * Sin(p) ^ 3
    Next I
'
'
'
End Sub
Public Sub Ellisse(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = acos(p)
'    y = bsin(p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = a * Cos(p)
        dY(I, 1) = b * Sin(p)
    Next I
'
'
'
End Sub
Public Sub Nefroide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = a(3cos(p) - cos(3p))
'    y = a(3sin(p) - sin(3p))
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        dX(I, 1) = a * (3# * Cos(p) - Cos(3# * p))
        dY(I, 1) = a * (3# * Sin(p) - Sin(3# * p))
    Next I
'
'
'
End Sub
Public Sub Trattrice(ByVal NPunti&, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione parametrica cartesiana:
'    x = 1/cosh(p)
'    y = p - tanh(p)
'
    Dim I&, p#, dt#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        dX(I, 1) = 1# / Cosh(p)
        dY(I, 1) = p - Tanh(p)
    Next I
'
'
'
End Sub
Public Sub Lituus(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = a/p
'
'   Di questa curva viene calcolata solo il primo
'   ramp per -dt <= p <= t; il secondo ramo
'   e' simmetrico al primo.
'
    Dim I&, dt#, p#, r#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / CDbl(NPunti)
'
    For I = 1 To NPunti
        p = dt * CDbl(I)
'
        r = a / Sqr(Abs(p))
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = -r * Sin(p)
    Next I
'
    For I = 1 To NPunti
        dX(I, 2) = -dX(I, 1)
        dY(I, 2) = -dY(I, 1)
    Next I
'
'
'
End Sub
Public Sub SpiraleFermat(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = ap
'
'   Di questa curva viene calcolata solo la prima
'   meta' per -t/2 <= p <= -dt1; la seconda meta'
'   e' simmetrica alla prima.
'   E':
'    dt1 = dt/2 se NPunti e' pari.
'    dt1 = dt   se NPunti e' dispari; in questo caso dX(N2+1) = dY(N2+1) = 0.
'
    Dim I&, N2&, dt#, p#, r#
'
    N2 = Int(NPunti / 2)
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To N2
        p = dt * CDbl(I - 1) - t / 2#
'
        r = a * Sqr(Abs(p))
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = -r * Sin(p)
    Next I
'
    For I = N2 + 1 To NPunti
        dX(I, 1) = -dX(NPunti + 1 - I, 1)
        dY(I, 1) = -dY(NPunti + 1 - I, 1)
    Next I
'
'
'
End Sub
Public Sub Cocleoide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = asin(p)/p
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I)
'
        r = a * (Sin(p)) / p
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub LumacaPascal(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = b + 2acos(p)
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = b + 2# * a * Cos(p)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub SpiraleArchimede(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = ap
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = a * p
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub Rosa(ByVal NPunti&, ByVal a#, ByVal b#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = asin(bp)
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = a * Sin(b * p)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub CurvaWatt(ByVal NPunti&, ByVal a#, ByVal b#, ByVal c#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = b - (asin(p)  sqr(c - acos(p)))
'
    Dim I&, dt#, p#, r#
    ReDim dX(1 To NPunti, 1 To 2)   ' Curva a
    ReDim dY(1 To NPunti, 1 To 2)   ' due rami.
'
    dt = t / CDbl(NPunti - 1)
'
    ' 1 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = b ^ 2 - (a * Sin(p) + Sqr(c ^ 2 - (a ^ 2) * (Cos(p)) ^ 2)) ^ 2
        r = Sqr(r)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
    ' 2 ramo:
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = b ^ 2 - (a * Sin(p) - Sqr(c ^ 2 - (a ^ 2) * (Cos(p)) ^ 2)) ^ 2
        r = Sqr(r)
        dX(I, 2) = r * Cos(p)
        dY(I, 2) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub Cardioide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = 2a(1 + cos(p))
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1)
'
        r = 2# * a * (1# + Cos(p))
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub Cissoide(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = 2atan(p)sin(p)
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I - 1) - t / 2#
'
        r = 2# * a * Tan(p) * Sin(p)
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
Public Sub SpiraleIperbolica(ByVal NPunti&, ByVal a#, ByVal t#, _
    ByRef dX#(), ByRef dY#())
'
'   Equazione polare:
'    r = a/p
'
    Dim I&, dt#, p#, r#
'
    dt = t / CDbl(NPunti - 1)
'
    For I = 1 To NPunti
        p = dt * CDbl(I)
'
        r = a / p
        dX(I, 1) = r * Cos(p)
        dY(I, 1) = r * Sin(p)
    Next I
'
'
'
End Sub
